@@ -1,7 +1,7 @@
 ###
-### R routines for the R package dlnm (c) Antonio Gasparrini 2012-2013
+### R routines for the R package dlnm (c) Antonio Gasparrini 2012-2014
 #
-`.onAttach` <- 
+.onAttach <- 
 function(lib, pkg) {
 #
 ################################################################################
