@@ -1,7 +1,7 @@
 ###
-### R routines for the R package dlnm (c) Antonio Gasparrini 2013
+### R routines for the R package dlnm (c) Antonio Gasparrini 2013-2014
 #
-`thr` <-
+thr <-
 function(x, thr.value=NULL, side=NULL, int=FALSE) {
 #
 ################################################################################
